*****************
Developer's Guide
*****************

This article describes the guidelines to be followed by developers working on this repository.
If you are planning on contributing to this repository please read the following carefully.
This guide borrows heavily from the one developed by the SunPy Project.
It is consistent with the `standards <https://github.com/heliophysicsPy/standards/blob/main/standards.md>`_ recommended by the `Python in Heliophysics (PyHC) <https://heliopython.org/>`_.

The guidelines are

.. toctree::
   :maxdepth: 2

   dev_env
   code_standards
   tests
   docs
   release